### Name: bmonomvn
### Title: Bayesian Estimation for Multivariate Normal Data with Monotone
###   Missingness
### Aliases: bmonomvn
### Keywords: multivariate regression

### ** Examples

## standard usage, duplicating the results in
## Little and Rubin, section 7.4.3
data(cement.miss)
out <- bmonomvn(cement.miss)
out
out$mu
out$S

##
## A bigger example, comparing the various methods
##

## generate N=1000 samples from a random MVN
xmuS <- randmvn(1000, 100)

## randomly impose monotone missingness
xmiss <- rmono(xmuS$x)

## using least squares only when necessary
out.b <- bmonomvn(xmiss)
out.b
kl.norm(out.b$mu, out.b$S, xmuS$mu, xmuS$S, symm=TRUE)
out.mle <- monomvn(xmiss, method="lasso")
kl.norm(out.mle$mu, out.mle$S, xmuS$mu, xmuS$S, symm=TRUE)

## using least squares sparingly
out.b.s <- bmonomvn(xmiss, p=0.25)
kl.norm(out.b.s$mu, out.b.s$S, xmuS$mu, xmuS$S, symm=TRUE)
out.mle.s <- monomvn(xmiss, p=0.25, method="lasso")
kl.norm(out.mle.s$mu, out.mle.s$S, xmuS$mu, xmuS$S, symm=TRUE)

## using the maximum likelihood solution to initialize
## the Markov chain and avoid burn-in.  
out.b2.s <- bmonomvn(xmiss, p=0.25, B=0, start=out.mle.s, method="rjlasso")
kl.norm(out.b2.s$mu, out.b2.s$S, xmuS$mu, xmuS$S, symm=TRUE)



