### Name: monomvn
### Title: Maximum Likelihood Estimation for Multivariate Normal Data with
###   Monotone Missingness
### Aliases: monomvn
### Keywords: multivariate regression

### ** Examples

## standard usage, duplicating the results in
## Little and Rubin, section 7.4.3 -- try adding 
## verb=3 argument for a step-by-step breakdown
data(cement.miss)
out <- monomvn(cement.miss)
out
out$mu
out$S

##
## A bigger example, comparing the various methods
##

## generate N=1000 samples from a random MVN
xmuS <- randmvn(1000, 100)

## randomly impose monotone missingness
xmiss <- rmono(xmuS$x)

## plsr
out.plsr <- monomvn(xmiss)
out.plsr
kl.norm(out.plsr$mu, out.plsr$S, xmuS$mu, xmuS$S)

## plcr
out.pcr <- monomvn(xmiss, method="pcr")
kl.norm(out.pcr$mu, out.pcr$S, xmuS$mu, xmuS$S)

## ridge regression
out.ridge <- monomvn(xmiss, method="ridge")
kl.norm(out.ridge$mu, out.ridge$S, xmuS$mu, xmuS$S)

## lasso
out.lasso <- monomvn(xmiss, method="lasso")
kl.norm(out.lasso$mu, out.lasso$S, xmuS$mu, xmuS$S)

## lar
out.lar <- monomvn(xmiss, method="lar")
kl.norm(out.lar$mu, out.lar$S, xmuS$mu, xmuS$S)

## forward.stagewise
out.fs <- monomvn(xmiss, method="forward.stagewise")
kl.norm(out.fs$mu, out.fs$S, xmuS$mu, xmuS$S)

## stepwise
out.step <- monomvn(xmiss, method="stepwise")
kl.norm(out.step$mu, out.step$S, xmuS$mu, xmuS$S)



